BaseLoggerService class abstract

Constructors

BaseLoggerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
privateLog(String msg, [String? debugTag]) → void
privateRecordError([dynamic err, StackTrace? st]) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BaseLoggerService?
getter/setter pair

Static Methods

log(String msg, [String? debugTag]) → void
recordError([dynamic err, StackTrace? st]) → void