Validators class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
codeValidation(
String? code, int minLength) → String? -
emailOrPhoneValidation(
String? text, {String? startWith}) → String? -
emailValidation(
String? email) → String? -
emptyValidation(
String? text, [int? maxLength]) → String? -
intValidation(
String? text) → String? -
nameValidation(
String? name, int minLength) → String? -
passwordValidation(
String? password, {int? minLength, int? maxLength}) → PasswordValidationResult -
phoneValidation(
String? text, {String? startWith}) → String? -
urlValidation(
String? text) → String?